@@ -1,6 +1,7 @@
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.model import find_primary_product
 from hestia_earth.utils.lookup import get_table_value, download_lookup
+from hestia_earth.utils.tools import list_sum, flatten
 
 from hestia_earth.validation.utils import _list_sum, _filter_list_errors
 
@@ -17,7 +18,7 @@ def validate_economicValueShare(products: list):
     }
 
 
-def validate_value(products: list):
+def validate_value_empty(products: list):
     def validate(values: tuple):
         index, product = values
         return len(product.get('value', [])) > 0 or {
@@ -29,6 +30,36 @@ def validate_value(products: list):
     return _filter_list_errors(map(validate, enumerate(products)))
 
 
+def validate_value_0(products: list):
+    def validate(values: tuple):
+        index, product = values
+        value = list_sum(product.get('value', [-1]), -1)
+        eva = product.get('economicValueShare')
+        revenue = product.get('revenue')
+        return value != 0 or _filter_list_errors([
+            eva == 0 or {
+                'level': 'error',
+                'dataPath': f".products[{index}].economicValueShare",
+                'message': 'must be 0 for product value 0',
+                'params': {
+                    'value': eva,
+                    'term': product.get('term')
+                }
+            },
+            revenue == 0 or {
+                'level': 'error',
+                'dataPath': f".products[{index}].revenue",
+                'message': 'must be 0 for product value 0',
+                'params': {
+                    'value': revenue,
+                    'term': product.get('term')
+                }
+            }
+        ])
+
+    return _filter_list_errors(flatten(map(validate, enumerate(products))))
+
+
 MAX_PRIMARY_PRODUCTS = 1
 
 
