@@ -2,10 +2,12 @@ import os
 from concurrent.futures import ThreadPoolExecutor
 from functools import reduce
 import re
+from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.tools import flatten, list_sum
+from hestia_earth.earth_engine.gee_utils import MAX_AREA_SIZE
 
 from hestia_earth.validation.geojson import get_geojson_area
-from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id
+from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id, get_region_size, get_boundary_size
 from hestia_earth.validation.utils import (
     update_error_path, _filter_list_errors, _next_error, _value_average,
     _find_linked_node, _is_before_today, run_model_from_node, run_model, _get_dict_key,
@@ -238,17 +240,43 @@ def validate_area(node: dict):
         return True
 
 
-MAX_AREA_SIZE = 5000  # in km2
-
-
 def validate_area_size(node: dict):
-    value = node.get('area', 0) / 100
-    return value < MAX_AREA_SIZE or {
+    area = node.get('area', 0) / 100
+    return area < MAX_AREA_SIZE or {
         'level': 'warning',
         'dataPath': '.area',
         'message': 'should be lower than max size',
         'params': {
-            'current': value,
+            'current': area,
+            'expected': MAX_AREA_SIZE
+        }
+    }
+
+
+def validate_boundary_size(node: dict):
+    boundary = node.get('boundary')
+    area = get_boundary_size(boundary) if boundary else 0
+    return area < MAX_AREA_SIZE or {
+        'level': 'warning',
+        'dataPath': '.boundary',
+        'message': 'should be lower than max size',
+        'params': {
+            'current': area,
+            'expected': MAX_AREA_SIZE
+        }
+    }
+
+
+def validate_region_size(node: dict):
+    region_id = node.get('region', node.get('country', {})).get('@id')
+    region = download_hestia(region_id) if region_id else {}
+    area = region.get('area', get_region_size(region_id) if region_id else None) or 0
+    return area < MAX_AREA_SIZE or {
+        'level': 'warning',
+        'dataPath': f".{'region' if node.get('region') else 'country'}",
+        'message': 'should be lower than max size',
+        'params': {
+            'current': area,
             'expected': MAX_AREA_SIZE
         }
     }
@@ -278,7 +306,7 @@ def validate_empty_fields(node: dict):
     return _filter_list_errors(map(validate, keys), False)
 
 
-def validate_linked_source_privacy(node: dict, key: str, node_map: dict):
+def validate_linked_source_privacy(node: dict, key: str, node_map: dict = {}):
     related_source = _find_linked_node(node_map, node.get(key, {}))
     node_privacy = node.get('dataPrivate')
     related_source_privacy = related_source.get('dataPrivate') if related_source else None
