@@ -68,6 +68,10 @@ def test_validate_soilTexture_invalid_percent():
             'dataPath': '.measurements[0].value',
             'message': 'is outside the allowed range',
             'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'sandContent'
+                },
                 'range': {'min': 86, 'max': 100}
             }
         },
@@ -76,6 +80,10 @@ def test_validate_soilTexture_invalid_percent():
             'dataPath': '.measurements[4].value',
             'message': 'is outside the allowed range',
             'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'sandContent'
+                },
                 'range': {'min': 20, 'max': 45}
             }
         },
@@ -84,6 +92,10 @@ def test_validate_soilTexture_invalid_percent():
             'dataPath': '.measurements[6].value',
             'message': 'is outside the allowed range',
             'params': {
+                'term': {
+                    '@type': 'Term',
+                    '@id': 'clayContent'
+                },
                 'range': {'min': 27, 'max': 40}
             }
         }
