@@ -2,7 +2,7 @@ import json
 
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.product import (
-    validate_economicValueShare, validate_value, validate_excreta, validate_primary
+    validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta, validate_primary
 )
 
 
@@ -28,25 +28,67 @@ def test_validate_economicValueShare_invalid():
     }
 
 
-def test_validate_value_valid():
+def test_validate_value_empty_valid():
     # no products should be valid
-    assert validate_value([]) is True
+    assert validate_value_empty([]) is True
 
     with open(f"{fixtures_path}/product/value/valid.json") as f:
         data = json.load(f)
-    assert validate_value(data.get('nodes')) is True
+    assert validate_value_empty(data.get('nodes')) is True
 
 
-def test_validate_value_warning():
-    with open(f"{fixtures_path}/product/value/warning.json") as f:
+def test_validate_value_empty_warning():
+    with open(f"{fixtures_path}/product/value/value-empty/warning.json") as f:
         data = json.load(f)
-    assert validate_value(data.get('nodes')) == {
+    assert validate_value_empty(data.get('nodes')) == {
         'level': 'warning',
         'dataPath': '.products[1]',
         'message': 'may not be 0'
     }
 
 
+def test_validate_value_0_valid():
+    # no products should be valid
+    assert validate_value_0([]) is True
+
+    with open(f"{fixtures_path}/product/value/valid.json") as f:
+        data = json.load(f)
+    assert validate_value_0(data.get('nodes')) is True
+
+
+def test_validate_value_0_error():
+    with open(f"{fixtures_path}/product/value/value-0/error.json") as f:
+        data = json.load(f)
+    assert validate_value_0(data.get('nodes')) == [
+        {
+            'level': 'error',
+            'dataPath': '.products[1].economicValueShare',
+            'message': 'must be 0 for product value 0',
+            'params': {
+                'value': None,
+                'term': {
+                    "@type": "Term",
+                    "name": "Generic Crop, grain",
+                    "@id": "genericCropGrain"
+                }
+            }
+        },
+        {
+            'level': 'error',
+            'dataPath': '.products[1].revenue',
+            'message': 'must be 0 for product value 0',
+            'params': {
+                'value': 100,
+                'term': {
+                    "@type": "Term",
+                    "name": "Generic Crop, grain",
+                    "@id": "genericCropGrain"
+                }
+            }
+        }
+    ]
+
+
 def test_validate_excreta_valid():
     # no products should be valid
     assert validate_excreta({}) is True
