@@ -1,3 +1,4 @@
+from unittest.mock import patch
 import json
 
 from tests.utils import fixtures_path
@@ -8,10 +9,13 @@ from hestia_earth.validation.validators.shared import (
     need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
-    validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size
+    validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
+    validate_boundary_size, validate_region_size
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
+class_path = 'hestia_earth.validation.validators.shared'
+
 
 def test_validate_dates():
     assert validate_dates({
@@ -244,13 +248,15 @@ def test_validate_area_invalid():
     }
 
 
-def test_validate_coordinates_valid():
+@patch(f"{class_path}.get_region_id", return_value='GADM-GBR')
+def test_validate_coordinates_valid(*args):
     with open(f"{fixtures_path}/shared/coordinates/valid.json") as f:
         node = json.load(f)
     assert validate_coordinates(node) is True
 
 
-def test_validate_coordinates_invalid():
+@patch(f"{class_path}.get_region_id", return_value='GADM-GBR')
+def test_validate_coordinates_invalid(*args):
     with open(f"{fixtures_path}/shared/coordinates/invalid.json") as f:
         node = json.load(f)
     assert validate_coordinates(node) == {
@@ -335,7 +341,7 @@ def test_validate_linked_source_privacy_valid():
         'dataPrivate': True
     }
     # valid if no connected source
-    assert validate_linked_source_privacy(node, 'source', {}) is True
+    assert validate_linked_source_privacy(node, 'source') is True
 
     source = {
         'type': 'Source',
@@ -389,10 +395,36 @@ def test_validate_linked_source_privacy_invalid():
     }
 
 
+@patch(f"{class_path}._find_linked_node")
+def test_validate_linked_source_privacy_indexed(mock_find_linked_node):
+    node = {
+        'source': {
+            '@type': 'Source',
+            '@id': '1'
+        },
+        'dataPrivate': True
+    }
+    mock_find_linked_node.return_value = {'dataPrivate': True}
+    assert validate_linked_source_privacy(node, 'source') is True
+
+    mock_find_linked_node.return_value = {'dataPrivate': False}
+    assert validate_linked_source_privacy(node, 'source') == {
+        'level': 'error',
+        'dataPath': '.dataPrivate',
+        'message': 'should have the same privacy as the related source',
+        'params': {
+            'dataPrivate': True,
+            'source': {
+                'dataPrivate': False
+            }
+        }
+    }
+
+
 def test_validate_date_lt_today_valid():
     key = 'date'
-    node = {key: '2000-01-01'}
-    assert validate_date_lt_today(node, key) is True
+    assert validate_date_lt_today({key: '2000-01-01'}, key) is True
+    assert validate_date_lt_today({key: '2022'}, key) is True
 
 
 def test_validate_date_lt_today_invalid():
@@ -641,3 +673,52 @@ def test_validate_area_size_warning():
             'expected': 5000
         }
     }
+
+
+@patch(f"{class_path}.get_boundary_size", return_value=2500)
+def test_validate_boundary_size_valid(*args):
+    # no boundary => valid
+    assert validate_boundary_size({}) is True
+    # boundary below max size => valid
+    assert validate_boundary_size({'boundary': True}) is True
+
+
+@patch(f"{class_path}.get_boundary_size", return_value=10000)
+def test_validate_boundary_size_warning(*args):
+    assert validate_boundary_size({'boundary': True}) == {
+        'level': 'warning',
+        'dataPath': '.boundary',
+        'message': 'should be lower than max size',
+        'params': {
+            'current': 10000,
+            'expected': 5000
+        }
+    }
+
+
+@patch(f"{class_path}.get_region_size", return_value=2500)
+@patch(f"{class_path}.download_hestia")
+def test_validate_region_size_valid(mock_download, *args):
+    # no region => valid
+    assert validate_region_size({}) is True
+
+    # with region without download => valid
+    assert validate_region_size({'area': 2500}) is True
+
+    # with region and download => valid
+    data = {'region': {'@id': 'GADM-FRA'}}
+    mock_download.return_value = {'area': 2500}
+    assert validate_region_size(data) is True
+
+
+@patch(f"{class_path}.get_region_size", return_value=10000)
+def test_validate_region_size_warning(*args):
+    assert validate_region_size({'country': {'@id': True}}) == {
+        'level': 'warning',
+        'dataPath': '.country',
+        'message': 'should be lower than max size',
+        'params': {
+            'current': 10000,
+            'expected': 5000
+        }
+    }
