@@ -10,10 +10,13 @@ from hestia_earth.validation.validators.site import (
 class_path = 'hestia_earth.validation.validators.site'
 
 
-def test_validate_valid():
+@patch(f"{class_path}.validate_boundary_size", return_value=True)
+@patch(f"{class_path}.validate_region_size", return_value=True)
+@patch(f"{class_path}.validate_coordinates", return_value=True)
+def test_validate_valid(*args):
     with open(f"{fixtures_path}/site/valid.json") as f:
         node = json.load(f)
-    assert validate_site(node) == [True] * 26
+    assert validate_site(node) == [True] * 28
 
 
 def test_validate_site_dates_valid():
@@ -45,7 +48,8 @@ def test_validate_site_coordinates(*args):
     assert not validate_site_coordinates(site)
 
 
-def test_validate_siteType_valid():
+@patch(f"{class_path}.fetch_data", return_value={'mean': 25})
+def test_validate_siteType_valid(*args):
     site = {
         'siteType': SiteSiteType.FOREST.value,
         'latitude': 44.18753,
@@ -61,7 +65,8 @@ def test_validate_siteType_valid():
     assert validate_siteType(site) is True
 
 
-def test_validate_siteType_invalid():
+@patch(f"{class_path}.fetch_data", return_value={'mean': 30})
+def test_validate_siteType_invalid(*args):
     site = {
         'siteType': SiteSiteType.CROPLAND.value,
         'latitude': 44.18753,
